GreaterThanRule class

A validation rule that checks if a value is greater than a specified minimum value.

Inheritance

Constructors

GreaterThanRule(num minValue, {String? errorMessage})
Creates a GreaterThanRule with the given minValue and optional errorMessage.
const

Properties

defaultMessage Map<String, String>
Default error messages for different locales.
no setteroverride
errorMessage String?
The error message to be displayed if validation fails.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
minValue num
The minimum value that the input must be greater than.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

isValid(BuildContext context, String? value) String?
Validates if the value is greater than minValue.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited