InListRule class

A validation rule that checks if a value is in a list of valid values.

Inheritance

Constructors

InListRule(List<String> values, {String? errorMessage})
Creates an InListRule with the given list of valid values and an optional errorMessage.
const

Properties

defaultMessage Map<String, String>
The default error messages for different locales.
no setteroverride
errorMessage String?
The error message to be displayed if validation fails.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
values List<String>
The list of valid values.
final

Methods

isValid(BuildContext context, String? value) String?
Validates if the value is in the list of valid values.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited