MatchRule class

A validation rule that checks if a value matches a given pattern.

Inheritance

Constructors

MatchRule(Pattern pattern, {String? errorMessage})
Creates a MatchRule with the given pattern and optional errorMessage.
const

Properties

defaultMessage Map<String, String>
Default error messages for different locales.
no setteroverride
errorMessage String?
The error message to be displayed if validation fails.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
pattern Pattern
The pattern to match against the value.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

isValid(BuildContext context, String? value) String?
Validates the value against the pattern.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited