MinLengthRule class

A validation rule that checks if the value has a minimum length.

Inheritance

Constructors

MinLengthRule(int minLength, {String? errorMessage})
Creates a MinLengthRule with the given minLength and optional errorMessage.
const

Properties

defaultMessage Map<String, String>
Default error messages for different locales.
no setteroverride
errorMessage String?
The error message to be displayed if validation fails.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
minLength int
The minimum number of characters required.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

isValid(BuildContext context, String? value) String?
Validates if the value has at least minLength characters.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited