NotInListExtensions extension
Extension on Validator to add a rule that checks if a value is not in a list.
- on
-
- Validator
Methods
-
notInList(
List< String> values, {String? errorMessage}) → Validator -
Available on Validator, provided by the NotInListExtensions extension
Adds a NotInListRule to the validator.