PhoneNumberRule class

A validation rule that checks if a value is a valid phone number.

Inheritance

Constructors

PhoneNumberRule(String? pattern, {String? errorMessage})
Creates a new PhoneNumberRule.
const

Properties

defaultMessage Map<String, String>
Default error messages for different locales.
no setteroverride
errorMessage String?
The error message to be displayed if validation fails.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
pattern String?
The regex pattern to validate the phone number.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

isValid(BuildContext context, String? value) String?
Validates the given value as a phone number.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited