flutter_vali library
Classes
- BetweenRule
- A rule that validates if a value is between a specified range.
- ContainsRule
- A rule that checks if a value contains a specific substring.
- CreditCardRule
- A validation rule that checks if a value is a valid credit card number.
- DateRule
- A validation rule that checks if a value is a valid date.
- DigitsOnlyRule
- A validation rule that checks if the input contains only digits.
- EmailRule
- A validation rule that checks if a value is a valid email address.
- EndsWithRule
- A validation rule that checks if a field value ends with a specific suffix.
- EqualToRule
- A validation rule that checks if a value is equal to a target value.
- GreaterThanOrEqualRule
- A validation rule that checks if a value is greater than or equal to a specified minimum value.
- GreaterThanRule
- A validation rule that checks if a value is greater than a specified minimum value.
- InListRule
- A validation rule that checks if a value is in a list of valid values.
- LengthRule
- A rule that validates the length of a value.
- LessThanOrEqualRule
- A validation rule that checks if a value is less than or equal to a specified maximum value.
- LessThanRule
- A validation rule that checks if a value is less than a specified maximum value.
- MatchRule
- A validation rule that checks if a value matches a given pattern.
- MaxLengthRule
- A validation rule that checks if the value's length does not exceed a maximum length.
- MinLengthRule
- A validation rule that checks if the value has a minimum length.
- NotEmptyRule
- A rule that checks if a value is not empty.
- NotInListRule
- A rule that checks if a value is not in a specified list of values.
- PhoneNumberRule
- A validation rule that checks if a value is a valid phone number.
- StartsWithRule
- A ValidatorRule that checks if a field starts with a specific prefix.
- ValidatorRule
- An abstract class representing a validation rule.
Extensions
- BetweenExtensions on Validator
-
Extension on
Validatorto add a between rule. - ContainsExtensions on Validator
-
Extension on
Validatorto add contains rule. - CreditCardExtensions on Validator
-
Extension on
Validatorto add credit card validation. - DateExtensions on Validator
-
Extension on
Validatorto add date validation. - DigitsOnlyExtensions on Validator
-
Extension on
Validatorto add a digits-only validation rule. - EmailExtensions on Validator
-
Extension on
Validatorto add email validation rule. - EndsWithExtensions on Validator
-
Extension on
Validatorto addendsWithvalidation rule. - EqualToExtensions on Validator
-
Extension on
Validatorto add equal to validation rule. - GreaterThanExtensions on Validator
-
Extension on
Validatorto add greater than validation rule. - GreaterThanOrEqualExtensions on Validator
-
Extension on
Validatorto add greater than or equal rule. - InListExtensions on Validator
-
Extension on
Validatorto add in-list validation rule. - LengthExtensions on Validator
-
Extension on
Validatorto add length validation. - LessThanExtensions on Validator
-
Extension on
Validatorto add a less than rule. - LessThanOrEqualExtensions on Validator
-
Extension on
Validatorto add less than or equal validation. - MatchExtensions on Validator
-
Extension on
Validatorto add match validation rule. - MaxLengthExtensions on Validator
-
Extension on
Validatorto add a max length validation rule. - MinLengthExtensions on Validator
-
Extension on
Validatorto add a minimum length validation rule. - NotEmptyExtensions on Validator
-
Extension on
Validatorto add a not empty rule. - NotInListExtensions on Validator
-
Extension on
Validatorto add a rule that checks if a value is not in a list. - PhoneNumberExtensions on Validator
-
Extension on
Validatorto add phone number validation. - StartsWithExtensions on Validator
-
Extension on
Validatorto add a rule that checks if a field starts with a specific prefix. - ValidatorExtensions on BuildContext
- Extension on BuildContext to provide validation utilities.