LessThanOrEqualRule class
A validation rule that checks if a value is less than or equal to a specified maximum value.
- Inheritance
-
- Object
- ValidatorRule
- LessThanOrEqualRule
Constructors
- LessThanOrEqualRule(num maxValue, {String? errorMessage})
-
Creates a new LessThanOrEqualRule.
const
Properties
-
defaultMessage
→ Map<
String, String> -
Default error messages in different languages.
no setteroverride
- errorMessage → String?
-
The error message to be displayed if validation fails.
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- maxValue → num
-
The maximum value allowed.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
isValid(
BuildContext context, String? value) → String? -
Validates if the
valueis less than or equal to maxValue.override -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited