StartsWithExtensions extension
Extension on Validator to add a rule that checks if a field starts with a specific prefix.
- on
-
- Validator
Methods
-
startsWith(
String prefix, {String? errorMessage}) → Validator -
Available on Validator, provided by the StartsWithExtensions extension
Adds a StartsWithRule to the validator.