StartsWithRule class
A ValidatorRule that checks if a field starts with a specific prefix.
- Inheritance
-
- Object
- ValidatorRule
- StartsWithRule
Constructors
- StartsWithRule(String prefix, {String? errorMessage})
-
Creates a StartsWithRule with the given
prefixand an optionalerrorMessage.const
Properties
-
defaultMessage
→ Map<
String, String> -
Default error messages for different locales.
no setteroverride
- errorMessage → String?
-
The error message to be displayed if validation fails.
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- prefix → String
-
The prefix that the field value should start with.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
isValid(
BuildContext context, String? value) → String? -
Validates if the
valuestarts with the prefix.override -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited